/*
 * Copyright (c) 2010 Jeff Schnitzer.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.googlecode.batchfb.err;

/**
 * <p>Thrown when a request to facebook times out or produces a http error code or returns totally
 * bogus data.  It may also happen if something goes wrong with JSON mapping.  This exception
 * is roughly equivalent to an unchecked version of IOException.</p>
 * 
 * <p>If this exception is insufficently granular (say, you need to distinguish JSON mapping
 * from HTTP errors), post an enhancement request to the BatchFB
 * <a href="http://code.google.com/p/batchfb/issues/list">issue tracker</a>.</p>
 * 
 * @author Jeff Schnitzer
 */
public class IOFacebookException extends FacebookException {
	private static final long serialVersionUID = 1L;
	
	/** Make GWT happy */
	IOFacebookException() {}

	public IOFacebookException(String message, Throwable cause) {
		super(message, cause);
	}
	
	public IOFacebookException(String message) {
		super(message);
	}
	
	public IOFacebookException(Throwable cause) {
		super(cause);
	}
}