/*
 * Copyright (c) 2010 Jeff Schnitzer.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.googlecode.batchfb.util;

import java.io.IOException;

import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.googlecode.batchfb.err.FacebookException;

/**
 * Some handy methods for working with JSON
 * 
 * @author Jeff Schnitzer
 */
public class JSONUtils {
	
	/**
	 * Converts the object to a JSON string using the mapper
	 */
	public static String toJSON(Object value, ObjectMapper mapper) {
		try {
			return mapper.writeValueAsString(value);
		} catch (IOException ex) {
			throw new FacebookException(ex);
		}
	}

	/**
	 * Parses a string into a JsonNode using the mapper
	 */
	public static JsonNode toNode(String value, ObjectMapper mapper) {
		try {
			return mapper.readTree(value);
		} catch (IOException ex) {
			throw new FacebookException(ex);
		}
	}
}